pub fn extra_syntax_set() -> SyntaxSetExpand description
Returns the precompiled SyntaxSet containing extra syntax definitions
not included in syntect’s defaults (e.g. TOML).
The syntax set is deserialized from a binary blob that was compiled at build time, so this is cheaper than parsing YAML definitions at runtime.